<?php
namespace FiloBlu\Newsletter\Model;

use Magento\Framework\Exception\LocalizedException as CoreException;

class ThankYou extends \Magento\Framework\Model\AbstractModel
{

    protected $thankYouPageCollectionFactory;

    /**
     * Store manager
     *
     * @var \Magento\Store\Model\StoreManagerInterface
     */
    protected $_storeManager;

    public function __construct(
        \FiloBlu\Newsletter\Model\ResourceModel\ThankYou\CollectionFactory $thankYouPageCollectionFactory,
        \Magento\Store\Model\StoreManagerInterface $_storeManager,
        \Magento\Framework\Model\Context $context,
        \Magento\Framework\Registry $registry,
        \Magento\Framework\Model\ResourceModel\AbstractResource $resource = null,
        \Magento\Framework\Data\Collection\AbstractDb $resourceCollection = null,
        array $data = []
    )
    {
        $this->thankYouPageCollectionFactory = $thankYouPageCollectionFactory;
        $this->_storeManager = $_storeManager;
        parent::__construct($context, $registry, $resource, $resourceCollection, $data);
    }

    /**
     * Initialize resource model
     *
     * @return void
     */
    protected function _construct()
    {
        $this->_init('FiloBlu\Newsletter\Model\ResourceModel\ThankYou');
    }


    public function getAvailableStatuses()
    {
        return array(
            0 => "Disabled",
            1 => "Enabled"
        );
    }

    public function beforeSave()
    {
        if (is_array($this->getData('store_ids'))) {
            $this->setData('store_ids', implode(',', $this->getData('store_ids')));
        }
        return parent::beforeSave();
    }

    public function getAllThankYouPage()
    {
        $collection = $this->thankYouPageCollectionFactory->create();
        $collection->addFieldToFilter('enabled', ["eq" => 1]);
        $collection->addStoreFilter($this->_storeManager->getStore()->getId());

        return $collection;
    }
    
    public function getAllUrlThankYouPage() {
        $collection = $this->getAllThankYouPage();
        $collection->addFieldToSelect(array('url_key','require_cookie'));

        return $collection;
    }

    public function getUrlThankYouPageById($id) {
        $collection = $this->getAllThankYouPage();
        $collection->addFieldToFilter('thankyou_id', ["eq" => $id]);
        $collection->addFieldToSelect(array('url_key'));
        
        return $collection->getFirstItem();
    }
    
    public function getThankYouPageById($id) {
        $collection = $this->getAllThankYouPage();
        $collection->addFieldToFilter('thankyou_id', ["eq" => $id]);
        
        return $collection->getFirstItem();
    }
    
    public function getThankYouPageList() {
        $collection = $this->thankYouPageCollectionFactory->create();
        $collection->addFieldToSelect(array('title', 'url_key'));
        
        return $collection;
    }
    
    public function getThankYouPageListArray() {
        $collection = $this->thankYouPageCollectionFactory->create();
        $collection->addFieldToSelect(array('title', 'url_key'));
        
        $array = array();
        
        $array[0] = "None";
        foreach ($collection->getData() as $value) {
            $array[$value["thankyou_id"]] = $value["title"] . " - " . $value["url_key"];
        }
        
        return $array;
    }
}